pype32.baseclasses.BaseStructClass

Package pype32 :: Module baseclasses :: Class BaseStructClass |
[hide private]
[frames] | no frames]

# Class BaseStructClass

source code

    object --+
             |
            BaseStructClass

Known Subclasses:
  - pype32.DosHeader
  - , directories.ExportTableEntry
  - , pype32.FileHeader
  - , directories.ImageBaseRelocationEntry
  - , directories.ImageBoundForwarderRefEntry
  - , directories.ImageBoundImportDescriptorEntry
  - , directories.ImageDebugDirectory
  - , directories.ImageExportTable
  - , directories.ImageImportDescriptorEntry
  - , directories.ImageImportDescriptorMetaData
  - , directories.ImportAddressTableEntry
  - , directories.ImportAddressTableEntry64
  - , directories.NETDirectory
  - , directories.NetDirectory
  - , directories.NetMetaDataHeader
  - , directories.NetMetaDataStreamEntry
  - , directories.NetMetaDataTableHeader
  - , directories.NetMetaDataTables
  - , pype32.NtHeaders
  - , pype32.OptionalHeader
  - , pype32.OptionalHeader64
  - , pype32.SectionHeader
  - , directories.TLSDirectory
  - , directories.TLSDirectory64

Base class containing methods used by many others classes in the library.

Instance Methods | [hide private]
__init__(self, shouldPack=True) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__len__(self) | source code
__str__(self) str(x) | source code
dict |
getFields(self) Returns all the class attributues. | source code
getType(self) This method should be implemented in the inherited classes. | source code
sizeof(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Parameters: `shouldPack` (bool) - (Optional) If the value is set to `True`, the class will be packed. If the value is set to `False`, the class will not be packed. Overrides: object.__init__

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### getFields(self) | source code
Returns all the class attributues. Returns: dict A dictionary containing all the class attributes.

### getType(self) | source code
This method should be implemented in the inherited classes. When implemented, returns an integer value to identified the corresponding class. Raises: `NotImplementedError` - The method wasn't implemented in the inherited class.